Index: contrib/OpenWRT/HOWTO
===================================================================
--- contrib/OpenWRT/HOWTO	(revision 491)
+++ contrib/OpenWRT/HOWTO	(revision 490)
@@ -90,7 +90,5 @@
 We will now describe how to install these dependencies. At the time this HOWTO is written, 
 the OpenWRT repositories contain ipv6, gnutls, pthreads and hostapd. Follow these instruction to
-build them.
-
-Alternatively, you can find these packages pre-compiled in the OpenWRT packages repository.
+build them:
 
 a) GNU TLS packages
Index: contrib/OpenWRT/packages/sctp/Makefile
===================================================================
--- contrib/OpenWRT/packages/sctp/Makefile	(revision 491)
+++ contrib/OpenWRT/packages/sctp/Makefile	(revision 489)
@@ -23,8 +23,18 @@
 
 include $(INCLUDE_DIR)/package.mk
+include $(INCLUDE_DIR)/kernel.mk
 
-#####
-## lksctp library: provides sctp_* functions in user space
-#####
+define KernelPackage/sctp
+  SUBMENU:=Network Support
+  TITLE:=SCTP support
+  KCONFIG:= CONFIG_IP_SCTP=m
+  FILES:=$(LINUX_DIR)/net/sctp/sctp.$(LINUX_KMOD_SUFFIX)
+  AUTOLOAD:=$(call AutoLoad,20,sctp)
+  DEPENDS:=@LINUX_2_6
+endef
+
+define KernelPackage/sctp/description
+ Kernel modules for SCTP support
+endef
 
 define Package/sctp
@@ -50,31 +60,3 @@
 
 $(eval $(call BuildPackage,sctp))
-
-
-#####
-## SCTP kernel support
-#####
-
-include $(INCLUDE_DIR)/kernel.mk
-
-define KernelPackage/sctp
-  SUBMENU:=Network Support
-  TITLE:=SCTP support
-  KCONFIG:=\
-     CONFIG_IP_SCTP=m \
-     CONFIG_LIBCRC32C=m
-  FILES:=\
-     $(LINUX_DIR)/net/sctp/sctp.$(LINUX_KMOD_SUFFIX) \
-     $(LINUX_DIR)/lib/libcrc32c.$(LINUX_KMOD_SUFFIX)
-  AUTOLOAD:=\
-     $(call AutoLoad,30,crc32c libcrc32c,1) \
-     $(call AutoLoad,35,sctp)
-  DEPENDS:=@LINUX_2_6 +kmod-crypto-core +kmod-crypto-misc
-endef
-
-define KernelPackage/sctp/description
- Kernel modules for SCTP support
-endef
-
 $(eval $(call KernelPackage,sctp))
-
Index: extensions/CMakeLists.txt
===================================================================
--- extensions/CMakeLists.txt	(revision 493)
+++ extensions/CMakeLists.txt	(revision 425)
@@ -15,5 +15,5 @@
 # The extensions include the headers of freeDiameter that contains gnutls objects
 FIND_PACKAGE(GnuTLS REQUIRED)
-INCLUDE_DIRECTORIES(${GNUTLS_INCLUDE_DIR})
+INCLUDE_DIRECTORIES(${GNUTLS_INCLUDE_DIRS})
 find_path(GCRYPT_INCLUDE_DIR NAMES gcrypt.h)
 If ( NOT GCRYPT_INCLUDE_DIR )
Index: freeDiameter/CMakeLists.txt
===================================================================
--- freeDiameter/CMakeLists.txt	(revision 493)
+++ freeDiameter/CMakeLists.txt	(revision 341)
@@ -51,5 +51,5 @@
 # Require GNU TLS for building the daemon
 FIND_PACKAGE(GnuTLS REQUIRED)
-INCLUDE_DIRECTORIES(${GNUTLS_INCLUDE_DIR})
+INCLUDE_DIRECTORIES(${GNUTLS_INCLUDE_DIRS})
 SET(FD_LIBS ${FD_LIBS} ${GNUTLS_LIBRARIES})
 find_path(GCRYPT_INCLUDE_DIR NAMES gcrypt.h)
Index: include/freeDiameter/CMakeLists.txt
===================================================================
--- include/freeDiameter/CMakeLists.txt	(revision 493)
+++ include/freeDiameter/CMakeLists.txt	(revision 378)
@@ -80,5 +80,5 @@
 	IF(NOT HAVE_NATIVE_SCTP)
 		FIND_PACKAGE(SCTP REQUIRED)
-		INCLUDE_DIRECTORIES(${SCTP_INCLUDE_DIR})
+		INCLUDE_DIRECTORIES(${SCTP_INCLUDE_DIRS})
 	ENDIF(NOT HAVE_NATIVE_SCTP)
 	# Now check the number of args of this function, since it changed between Ubuntu 9.04 and 9.10
@@ -90,5 +90,4 @@
 		}
 		")
-	SET(CMAKE_REQUIRED_INCLUDES ${SCTP_INCLUDE_DIR})
 	SET(CMAKE_REQUIRED_LIBRARIES ${SCTP_LIBRARIES})
 	CHECK_C_SOURCE_COMPILES("${CHECK_SCTP_CONNECTX_4_ARGS_SOURCE_CODE}" SCTP_CONNECTX_4_ARGS)

Index: cmake/Modules/FindGnuTLS.cmake
===================================================================
--- cmake/Modules/FindGnuTLS.cmake	(revision 493)
+++ cmake/Modules/FindGnuTLS.cmake	(revision 304)
@@ -3,10 +3,10 @@
 #
 #  GNUTLS_FOUND - True if gnutls found.
 #  GNUTLS_INCLUDE_DIR - where to find gnutls.h, etc.
 #  GNUTLS_LIBRARIES - List of libraries when using gnutls.
 
-if (GNUTLS_INCLUDE_DIR AND GNUTLS_LIBRARIES)
+if (GNUTLS_INCLUDE_DIRS AND GNUTLS_LIBRARIES)
   set(GNUTLS_FIND_QUIETLY TRUE)
-endif (GNUTLS_INCLUDE_DIR AND GNUTLS_LIBRARIES)
+endif (GNUTLS_INCLUDE_DIRS AND GNUTLS_LIBRARIES)
 
 # Include dir
@@ -3,10 +3,10 @@
 #
 #  GNUTLS_FOUND - True if gnutls found.
-#  GNUTLS_INCLUDE_DIR - where to find gnutls.h, etc.
+#  GNUTLS_INCLUDE_DIRS - where to find gnutls.h, etc.
 #  GNUTLS_LIBRARIES - List of libraries when using gnutls.
 
Index: cmake/Modules/FindSCTP.cmake
===================================================================
--- cmake/Modules/FindSCTP.cmake	(revision 493)
+++ cmake/Modules/FindSCTP.cmake	(revision 284)
@@ -3,10 +3,10 @@
 #
 #  SCTP_FOUND - system has SCTP
 #  SCTP_INCLUDE_DIR - the SCTP include directories
 #  SCTP_LIBRARIES - link these to use SCTP
 
-if (SCTP_INCLUDE_DIR AND SCTP_LIBRARIES)
+if (SCTP_INCLUDE_DIRS AND SCTP_LIBRARIES)
   set(SCTP_FIND_QUIETLY TRUE)
-endif (SCTP_INCLUDE_DIR AND SCTP_LIBRARIES)
+endif (SCTP_INCLUDE_DIRS AND SCTP_LIBRARIES)
 
 # Include dir
@@ -3,10 +3,10 @@
 #
 #  SCTP_FOUND - system has SCTP
-#  SCTP_INCLUDE_DIR - the SCTP include directories
+#  SCTP_INCLUDE_DIRS - the SCTP include directories
 #  SCTP_LIBRARIES - link these to use SCTP
 
Index: freeDiameter/tests/testfifo.c
===================================================================
--- freeDiameter/tests/testfifo.c	(revision 10)
+++ freeDiameter/tests/testfifo.c	(revision 494)
@@ -212,5 +212,5 @@
 		/* Initialize the ts */
 		CHECK(0, clock_gettime(CLOCK_REALTIME, &ts));
-		ts.tv_sec += 2; /* Set the timeout to 2 second */
+		ts.tv_sec += 20; /* Set the timeout to 20 second */
 		
 		/* Create the messages */
@@ -282,5 +282,5 @@
 		/* Initialize the ts */
 		CHECK(0, clock_gettime(CLOCK_REALTIME, &ts));
-		ts.tv_sec += 2; /* Set the timeout to 2 second */
+		ts.tv_sec += 10; /* Set the timeout to 10 second */
 		
 		/* Initialize the test data structures */